importSpectronaut.RdImport data from a Spectronaut quantification file into a
SingleCellExperiment object. Note that Spectronaut support in einprot
is currently experimental - please be aware that the interface may change,
and interpret results with caution.
importSpectronaut(
inFile,
fileType = "pg_pivot",
outLevel = "pg",
iColPattern = ".PG.Quantity$",
includeOnlySamples = "",
excludeSamples = "",
stopIfEmpty = FALSE,
aName = "PG.Quantity",
filtersDF = list(),
...
)Path to a tab-delimited input text file from Spectronaut.
Character scalar indicating the type of input file; either
"pg_pivot" or "long_format".
Character scalar indicating the desired output level;
currently only "pg" (protein group) is supported.
Character scalar defining a regular expression to
identify sample columns (only used if fileType is
"pg_pivot". This is typically
one of ".PG.Quantity$" or ".PG.IBAQ$". Columns matching the
given pattern will form the first assay in the output object.
Character vectors defining regular expressions to match against the extracted columns to retain or exclude samples.
Logical scalar, whether to raise an error if no columns matching the patterns are found.
Character scalar giving the column from which to get the
values for the main assay. Only used if fileType is
"long_format".
Named list where each element is a filtering function
that takes a data.frame as
input and returns a filtered data.frame. No other
arguments are allowed. The filtering functions will be applied in the
order they are provided in the list, after reading the long-format text
file, and before creating the wide-format assay. Only
applies if fileType is "long_format".
Additional arguments that will be passed on to
QFeatures::readSummarizedExperiment (e.g., the number of rows
to import).
A list with two elements: a SingleCellExperiment object and
a character scalar with the main assay name.