plotFractionDetectedPerSample.RdPlot the fraction of detected features in each sample.
plotFractionDetectedPerSample(dfNA, valueType = NULL)A DFrame or data.frame with at least columns
named "name" and "pNA" representing the sample name and
the fraction of missing values.
A character scalar indicating whether the values
in the "pNA" column represent fractions
(valueType = "fraction", values in [0, 1]) or
percentages (valueType = "percentage", values in [0, 100]). If
NULL, the type will be guessed from the observed values.
A ggplot object.
sce <- readRDS(system.file("extdata", "mq_example", "1356_sce.rds",
package = "einprot"))
plotFractionDetectedPerSample(SummarizedExperiment::colData(sce),
valueType = "percentage")